package http

import (
	"fmt"
	"net/http"

	"github.com/mediocregopher/blog.mediocregopher.com/srv/http/apiutil"
	"github.com/mediocregopher/blog.mediocregopher.com/srv/post"
)

func (a *api) manageDraftPostsHandler() http.Handler {

	tpl := a.mustParseBasedTpl("draft-posts-manage.html")
	const pageCount = 20

	return http.HandlerFunc(func(rw http.ResponseWriter, r *http.Request) {

		page, err := apiutil.StrToInt(r.FormValue("p"), 0)
		if err != nil {
			apiutil.BadRequest(
				rw, r, fmt.Errorf("invalid page number: %w", err),
			)
			return
		}

		posts, hasMore, err := a.params.PostDraftStore.Get(page, pageCount)
		if err != nil {
			apiutil.InternalServerError(
				rw, r, fmt.Errorf("fetching page %d of posts: %w", page, err),
			)
			return
		}

		tplPayload := struct {
			Posts              []post.Post
			PrevPage, NextPage int
		}{
			Posts:    posts,
			PrevPage: -1,
			NextPage: -1,
		}

		if page > 0 {
			tplPayload.PrevPage = page - 1
		}

		if hasMore {
			tplPayload.NextPage = page + 1
		}

		executeTemplate(rw, r, tpl, tplPayload)
	})
}

func (a *api) postDraftPostHandler() http.Handler {
	return http.HandlerFunc(func(rw http.ResponseWriter, r *http.Request) {

		p, err := postFromPostReq(r)
		if err != nil {
			apiutil.BadRequest(rw, r, err)
			return
		}

		if err := a.params.PostDraftStore.Set(p); err != nil {
			apiutil.InternalServerError(
				rw, r, fmt.Errorf("storing post with id %q: %w", p.ID, err),
			)
			return
		}

		a.executeRedirectTpl(rw, r, a.editDraftPostURL(p.ID, false))
	})
}
